/**************************************************************************

  File:        acnav-filt.c

  Simple filter to strip out the valid ship and non-ship records from 
  an ACNAC data file and fix the date-time fields into a single column
  of data (eg replace leading spaces with zeros).

  This is a true filter - it reads from STDIN and writes to STDOUT.

  Converts DOS files (CR-LF) to UNIX files (LF only) while it's at it.

  Written by Greg Herlein, SSSG Tech, R/V Atlantis, WHOI - 11/9/97


**************************************************************************/

/****** INCLUDES *********************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <string.h>
#include <unistd.h>



int main(int argc, char *argv[])
{
  char*                 p;
  FILE*                 fpIn;
  char                  szTemp[128];
  char                  szOut[256];
  int                   i;
  
  fpIn=stdin;

  while(1){
    memset(szOut,0x00,sizeof(szOut));
    memset(szTemp,0x00,sizeof(szTemp));
    p=fgets(szTemp,sizeof(szTemp),fpIn);
    /* if an error occured */
    if(p==NULL) {
      if(ferror(fpIn)!=0) {
	perror("file error");
	return -1;
      }
      if(feof(fpIn)==0) {
	fclose(fpIn);
	break;
      }
      if(feof(fpIn)!=0) {
	fclose(fpIn);
	break;
      }
    } /* end while */

    /* ensure there are no \r's left */
    p=strchr(szTemp,'\r');
    if (p!=NULL) {
      p[0]='\n';
      p[1]=0x00;
    }

    /* keep only lines that start in '2' or '4' */
    if( (*szTemp=='2')||(*szTemp=='4') ) {
      for(i=0;i<14;i++) {
	if(szTemp[i]==' ') szTemp[i]='0';
      }
      szOut[0]=szTemp[0];
      szOut[1]=' ';
      strncpy(szOut+2,szTemp+1,6);
      strcat(szOut," ");
      strncpy(szOut+9,szTemp+7,sizeof(szTemp));
      fputs(szOut,stdout);
    }
    
    /* loop again! */

  }
  fclose(fpIn);
  return 0;
}
